@@ -1,4 +1,4 @@
-from typing import List, Optional, Collection, Union, Any
+from typing import List, Optional, Collection, Union, Any, Final
 
 from dict_caster import DictCaster, Item, OneOf
 
@@ -13,8 +13,18 @@ from .table_base import TableBase
 from ..engine.merge_tree import MergeTree
 from ..exceptions import WrongArgumentsException
 
-ALL_COLUMNS_COLUMN_NAME = "*"
-ALL_COLUMNS = ["*"]
+
+class AllColumns:
+    pass
+
+
+ALL_COLUMNS = AllColumns()
+
+ALL_COLUMNS_COLUMN_NAME: Final[str] = "*"
+
+
+OrderRepresentations = Optional[list[Union[dict[str, str], str]]]
+ColumnsRepresentations = Optional[Union[List[str], AllColumns]]
 
 
 class Table(TableBase):
@@ -33,9 +43,12 @@ class Table(TableBase):
         raise RuntimeError()
 
     @classmethod
-    def columns_from_str(cls, column_names: Optional[Collection[str]]) -> Optional[List[Column]]:
+    def columns_from_str(cls, column_names: ColumnsRepresentations) -> Optional[List[Column]]:
         if column_names is None:
             return None
+        if isinstance(column_names, AllColumns):
+            return list(cls.get_columns())
+
         columns = []
         for column_name in column_names:
             if column_name == ALL_COLUMNS_COLUMN_NAME:
@@ -81,23 +94,24 @@ class Table(TableBase):
         return filters
 
     @classmethod
-    def orders_from_str(cls, str_orders: Optional[Union[Collection[dict], str]]) -> List[Order]:
-        if str_orders is None:
-            str_orders = []
+    def orders_from_str(cls, order_representations: OrderRepresentations) -> List[Order]:
+        if order_representations is None:
+            order_representations = []
         orders = []
         ascending_default = True
-        for str_order in str_orders:
-            if isinstance(str_order, str):
-                order = Order(str_order, ascending_default)
-            else:
-                parsed = DictCaster([
+        order_representation_caster = DictCaster([
                     OneOf(
-                        Item("column", str),
-                        Item("attribute", str, rename="column")
+                        Item("column", str, postprocessor=cls.column_from_str),
+                        Item("attribute", str, rename="column", postprocessor=cls.column_from_str),
                     ),
                     Item("ascending", bool, default=ascending_default),
-                ]).cast(str_order)
-                order = Order(**parsed)
+                ])
+        for representation in order_representations:
+            if isinstance(representation, str):
+                order = Order(cls.column_from_str(representation), ascending_default)
+            else:
+                representation_dict = order_representation_caster.cast(representation)
+                order = Order(**representation_dict)
             orders.append(order)
         return orders
 
